==> haskell-hspec-smallcheck-0.5.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-2vkF4tDbHim5BCcAT3CQu8
key: hspec-smallcheck-0.5.2-2vkF4tDbHim5BCcAT3CQu8
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 96d3227851d52705728c1da80c2f90ee
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-2vkF4tDbHim5BCcAT3CQu8
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.0-A1mY8UkXgxdD2IiW3Iltvu
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.2-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-9LHuGcJrdpWCVDNpmUrTWw
key: hspec-smallcheck-0.5.2-9LHuGcJrdpWCVDNpmUrTWw
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: c912e36f8cde8472eb23f5e73964cf58
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-9LHuGcJrdpWCVDNpmUrTWw
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.0-JrARMmO11lFBE82excsNgV
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
